@@ -95,6 +95,59 @@ model2layers = {
     "google/bert_uncased_L-12_H-256_A-4": 11,  # 0.6374004994430261
     "google/bert_uncased_L-12_H-512_A-8": 10,  # 0.65880012149526
     "google/bert_uncased_L-12_H-768_A-12": 9,  # 0.675911357700092
+    "amazon/bort": 0,  # 0.41927911053036643
+    "facebook/bart-base": 6,  # 0.7122259132414092
+    "facebook/bart-large": 10,  # 0.7448671872459683
+    "facebook/bart-large-cnn": 10,  # 0.7393148105835096
+    "facebook/bart-large-mnli": 11,  # 0.7531665445691358
+    "facebook/bart-large-xsum": 9,  # 0.7496408866539556
+    "t5-small": 6,  # 0.6813843919496912
+    "t5-base": 11,  # 0.7096044814981418
+    "t5-large": 23,  # 0.7244153820191929
+    "vinai/bertweet-base": 9,  # 0.6529471006118857
+    "microsoft/deberta-base": 9,  # 0.7088459455930344
+    "microsoft/deberta-base-mnli": 9,  # 0.7395257063907247
+    "microsoft/deberta-large": 16,  # 0.7511806792052013
+    "microsoft/deberta-large-mnli": 18,  # 0.7736263649679905
+    "microsoft/deberta-xlarge": 18,  # 0.7568670944373346
+    "microsoft/deberta-xlarge-mnli": 40,  # 0.7780600929333213
+    "YituTech/conv-bert-base": 10,  # 0.7058253551080789
+    "YituTech/conv-bert-small": 10,  # 0.6544473011107349
+    "YituTech/conv-bert-medium-small": 9,  # 0.6590097075123257
+    "microsoft/mpnet-base": 8,  # 0.724976539498804
+    "squeezebert/squeezebert-uncased": 9,  # 0.6543868703018726
+    "squeezebert/squeezebert-mnli": 9,  # 0.6654799051284791
+    "squeezebert/squeezebert-mnli-headless": 9,  # 0.6654799051284791
+    "tuner007/pegasus_paraphrase": 15,  # 0.7188349436772694
+    "google/pegasus-large": 8,  # 0.63960462272448
+    "google/pegasus-xsum": 11,  # 0.6836878575233349
+    "sshleifer/tiny-mbart": 2,  # 0.028246072231946733
+    "facebook/mbart-large-cc25": 12,  # 0.6582922975802958
+    "facebook/mbart-large-50": 12,  # 0.6464972230103133
+    "facebook/mbart-large-en-ro": 12,  # 0.6791285137459857
+    "facebook/mbart-large-50-many-to-many-mmt": 12,  # 0.6904136529270892
+    "facebook/mbart-large-50-one-to-many-mmt": 12,  # 0.6847906439540236
+    "allenai/led-base-16384": 6,  # 0.7122259170564179
+    "facebook/blenderbot_small-90M": 7,  # 0.6489176335400088
+    "facebook/blenderbot-400M-distill": 2,  # 0.5874774070540008
+    "microsoft/prophetnet-large-uncased": 4,  # 0.586496184234925
+    "microsoft/prophetnet-large-uncased-cnndm": 7,  # 0.6478379437729287
+    "SpanBERT/spanbert-base-cased": 8,  # 0.6824006863686848
+    "SpanBERT/spanbert-large-cased": 17,  # 0.705352690855603
+    "microsoft/xprophetnet-large-wiki100-cased": 7,  # 0.5852499775879524
+    "ProsusAI/finbert": 10,  # 0.6923213940752796
+    "Vamsi/T5_Paraphrase_Paws": 12,  # 0.6941611753807352
+    "ramsrigouthamg/t5_paraphraser": 11,  # 0.7200917597031539
+    "microsoft/deberta-v2-xlarge": 10,  # 0.7393675784473045
+    "microsoft/deberta-v2-xlarge-mnli": 17,  # 0.7620620803716714
+    "microsoft/deberta-v2-xxlarge": 21,  # 0.7520547670281869
+    "microsoft/deberta-v2-xxlarge-mnli": 22,  # 0.7742603457742682
+    "allenai/longformer-base-4096": 7,  # 0.7089559593129316
+    "allenai/longformer-large-4096": 14,  # 0.732408493548181
+    "allenai/longformer-large-4096-finetuned-triviaqa": 14,  # 0.7365882744744722
+    "zhiheng-huang/bert-base-uncased-embedding-relative-key": 4,  # 0.5995636595368777
+    "zhiheng-huang/bert-base-uncased-embedding-relative-key-query": 7,  # 0.6303599452145718
+    "zhiheng-huang/bert-large-uncased-whole-word-masking-embedding-relative-key-query": 19,  # 0.6896878492850327
 }
 
 
@@ -107,12 +160,15 @@ def sent_encode(tokenizer, sent):
         # for RoBERTa and GPT-2
         if LooseVersion(trans_version) >= LooseVersion("4.0.0"):
             return tokenizer.encode(
-                sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.model_max_length,
-                truncation=True
+                sent,
+                add_special_tokens=True,
+                add_prefix_space=True,
+                max_length=tokenizer.model_max_length,
+                truncation=True,
             )
         elif LooseVersion(trans_version) >= LooseVersion("3.0.0"):
             return tokenizer.encode(
-                sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.max_len, truncation=True
+                sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.max_len, truncation=True,
             )
         elif LooseVersion(trans_version) >= LooseVersion("2.0.0"):
             return tokenizer.encode(sent, add_special_tokens=True, add_prefix_space=True, max_length=tokenizer.max_len)
@@ -120,8 +176,9 @@ def sent_encode(tokenizer, sent):
             raise NotImplementedError(f"transformers version {trans_version} is not supported")
     else:
         if LooseVersion(trans_version) >= LooseVersion("4.0.0"):
-            return tokenizer.encode(sent, add_special_tokens=True, max_length=tokenizer.model_max_length,
-                                    truncation=True)
+            return tokenizer.encode(
+                sent, add_special_tokens=True, max_length=tokenizer.model_max_length, truncation=True,
+            )
         elif LooseVersion(trans_version) >= LooseVersion("3.0.0"):
             return tokenizer.encode(sent, add_special_tokens=True, max_length=tokenizer.max_len, truncation=True)
         elif LooseVersion(trans_version) >= LooseVersion("2.0.0"):
@@ -133,10 +190,17 @@ def sent_encode(tokenizer, sent):
 def get_model(model_type, num_layers, all_layers=None):
     if model_type.startswith("scibert"):
         model = AutoModel.from_pretrained(cache_scibert(model_type))
+    elif "t5" in model_type:
+        from transformers import T5EncoderModel
+
+        model = T5EncoderModel.from_pretrained(model_type)
     else:
         model = AutoModel.from_pretrained(model_type)
     model.eval()
 
+    if hasattr(model, "decoder") and hasattr(model, "encoder"):
+        model = model.encoder
+
     # drop unused layers
     if not all_layers:
         if hasattr(model, "n_layers"):  # xlm
@@ -174,8 +238,8 @@ def get_model(model_type, num_layers, all_layers=None):
             model.encoder.output_hidden_states = True
         elif hasattr(model, "transformer"):
             model.transformer.output_hidden_states = True
-        else:
-            raise ValueError(f"Not supported model architecture: {model_type}")
+        # else:
+        #     raise ValueError(f"Not supported model architecture: {model_type}")
 
     return model
 
@@ -183,7 +247,7 @@ def get_model(model_type, num_layers, all_layers=None):
 def get_tokenizer(model_type):
     if model_type.startswith("scibert"):
         model_type = cache_scibert(model_type)
-    
+
     if LooseVersion(trans_version) >= LooseVersion("4.0.0"):
         tokenizer = AutoTokenizer.from_pretrained(model_type, use_fast=False)
     else:
@@ -206,7 +270,7 @@ def padding(arr, pad_token, dtype=torch.long):
 def bert_encode(model, x, attention_mask, all_layers=False):
     model.eval()
     with torch.no_grad():
-        out = model(x, attention_mask=attention_mask)
+        out = model(x, attention_mask=attention_mask, output_hidden_states=all_layers)
     if all_layers:
         emb = torch.stack(out[-1], dim=2)
     else:
@@ -296,7 +360,7 @@ def get_bert_embedding(all_sens, model, tokenizer, idf_dict, batch_size=-1, devi
     with torch.no_grad():
         for i in range(0, len(all_sens), batch_size):
             batch_embedding = bert_encode(
-                model, padded_sens[i : i + batch_size], attention_mask=mask[i : i + batch_size], all_layers=all_layers
+                model, padded_sens[i : i + batch_size], attention_mask=mask[i : i + batch_size], all_layers=all_layers,
             )
             embeddings.append(batch_embedding)
             del batch_embedding
@@ -369,7 +433,9 @@ def greedy_cos_idf(ref_embedding, ref_masks, ref_idf, hyp_embedding, hyp_masks,
         F = F.view(L, B)
 
     if torch.any(hyp_zero_mask):
-        print("Warning: Empty candidate sentence detected; setting precision to be 0.", file=sys.stderr)
+        print(
+            "Warning: Empty candidate sentence detected; setting precision to be 0.", file=sys.stderr,
+        )
         P = P.masked_fill(hyp_zero_mask, 0.0)
 
     if torch.any(ref_zero_mask):
@@ -382,7 +448,7 @@ def greedy_cos_idf(ref_embedding, ref_masks, ref_idf, hyp_embedding, hyp_masks,
 
 
 def bert_cos_score_idf(
-    model, refs, hyps, tokenizer, idf_dict, verbose=False, batch_size=64, device="cuda:0", all_layers=False
+    model, refs, hyps, tokenizer, idf_dict, verbose=False, batch_size=64, device="cuda:0", all_layers=False,
 ):
     """
     Compute BERTScore.
@@ -478,7 +544,7 @@ def cache_scibert(model_type, cache_folder="~/.cache/torch/transformers"):
         return model_type
 
     underscore_model_type = model_type.replace("-", "_")
-    cache_folder = os.path.abspath(cache_folder)
+    cache_folder = os.path.abspath(os.path.expanduser(cache_folder))
     filename = os.path.join(cache_folder, underscore_model_type)
 
     # download SciBERT models
